### Summary

(Summarize the bug encountered concisely)

### Steps to reproduce

(How one can reproduce the issue - this is very important)
(Mention the OS and Gramex version. If relevant, Browser version and Anaconda/Python/Pandas/library version)

### What is the current *bug* behavior?

(What actually happens. Paste screenshot. Add logs. Format logs inside code blocks (```) - else it's very hard to read. Link to a page on demo/uat.gramener.com if possible.)

### What is the expected *correct* behavior?

(What you should see instead)

### Possible fixes

(If you can, link to the line of code thay might be responsible for the problem. Or suggest where you think the problem might be.)

/label ~bug
